Contributing to Opps
====================

As an open source project, Opps welcomes contributions of many forms.

Examples of contributions include:

* Code patches
* Documentation improvements
* Bug reports and patch reviews
* Write CHANGELOG

**Warning: pull requests are ignored!** `File a ticket`__ to suggest changes.

__ https://github.com/opps/opps/issues
